﻿/* 
==============================================================================
	PlanesTest demonstrates how to build and present a World3D using Sandy
   	It is a slightly modified version of kiroukous transform_a_first_box example
===============================================================================
*/
import sandy.core.data.*;
import sandy.core.group.*;
import sandy.primitive.*;
import sandy.view.*;
import sandy.core.*;
import sandy.skin.*;
import sandy.util.*;
import sandy.core.transform.*;
import sandy.events.*;

var screen:ClipScreen;	// Presentation surface
var world:World3D = World3D.getInstance(); // Our 3D world

function init( Void ):Void {
	// Create a clipScreen as presentation surface for the World3D to draw on
	screen = new ClipScreen( this.createEmptyMovieClip('screen', 1), 200, 200 );
	// Create a camera, so we can see our world. 
	// Give it a focal distanse ( equivalent ) and a reference to the viewing screen.
	var cam:Camera3D = new Camera3D( 700, screen );
	// Position the camera at a negative distance along the z axis
	// By default it is looking at the origin of the world coordinate system [0,0,0]
	cam.setPosition(50,150,-500);
	cam.lookAt(0,0,0);
	// Attach the camera to the world
	world.addCamera( cam );
	// Create the root group, the banch node for all objects in our world
	var bg:Group = new Group();
	// and attach it to the world. this node is responisble 
	// for drawing all its ( possibly transformed child nodes
	world.setRootGroup( bg );
	// Create the scen and attach it to the rootGroup
	createScene( bg );
	// Finally we start rendering the world
	world.render();
}

function createScene( bg:Group ):Void {
	// First we create the coordiante planes
	var xyPlane:Object3D = new Plane3D(100,100,10,'quad');
	xyPlane.setSkin( new MixedSkin(0x00FF00, 20, 0, 40, 1));
	
	var yzPlane:Object3D = new Plane3D(100,100,10,'quad');
	yzPlane.setSkin( new MixedSkin(0x0000FF, 20, 0, 40, 1));

	var zxPlane:Object3D = new Plane3D(100,100,10,'quad');
	zxPlane.setSkin( new MixedSkin(0xFF0000, 20, 0, 40, 1));

	// Then we create the rotations for the xy plane and the yz plane
	var tg1:TransformGroup = new TransformGroup();
	var rot1:Transform3D = new Transform3D();
	rot1.rot(90,0,0);
	tg1.setTransform( rot1 );
	tg1.addChild( xyPlane );
	
	var tg2:TransformGroup = new TransformGroup();
	var rot2:Transform3D = new Transform3D();
	rot2.rot(0,0,90);
	tg2.setTransform( rot2 );
	tg2.addChild( yzPlane );
	// The zx plane doesn't need any transformation
	
	// let's add the coorDinate axes - no transform applied
	var xAxis:Object3D = new Line3D( new Vector(-150,0,0), new Vector(150,0,0) );
	var yAxis:Object3D = new Line3D( new Vector(0,-150,0), new Vector(0,150,0) );
	var zAxis:Object3D = new Line3D( new Vector(0,0,-150), new Vector(0,0,150) );
	// Give the axes distinct colors
	xAxis.setSkin( new SimpleLineSkin( 1, 0xff0000, 100 ) ); // red
	yAxis.setSkin( new SimpleLineSkin( 1, 0x00ff00, 100 ) ); // green
	zAxis.setSkin( new SimpleLineSkin( 1, 0x0000ff, 100 ) ); // blue
	// Create the coorniate system group
	var coords:Group = new Group();
	coords.addChild(xAxis);
	coords.addChild(yAxis);
	coords.addChild(zAxis);
	// Add the coordinate system to the rootGroup
	bg.addChild( coords);
	// And finally the transformed coordinat planes to the rootGroup
	bg.addChild( tg1 );
	bg.addChild( tg2 );
	bg.addChild( zxPlane );
}
// Start creating the world
init();