﻿/* 
==============================================================================
	BoxTest demonstrates how to build and present a World3D using Sandy
   	It is a slightly modified version of kiroukous transform_a_first_box example
===============================================================================
*/
import sandy.core.data.*;
import sandy.core.group.*;
import sandy.primitive.*;
import sandy.view.*;
import sandy.core.*;
import sandy.skin.*;
import sandy.util.*;
import sandy.core.transform.*;
import sandy.events.*;

var screen:ClipScreen;	// Presentation surface
var world:World3D = World3D.getInstance(); // Our 3D world

function init( Void ):Void {
	// Create a clipScreen as presentation surface for the World3D to draw on
	screen = new ClipScreen( this.createEmptyMovieClip('screen', 1), 200, 200 );
	// Create a camera, so we can see our world. 
	// Give it a focal distanse ( equivalent ) and a reference to the viewing screen.
	var cam:Camera3D = new Camera3D( 700, screen );
	// Position the camera at a negative distance along the z axis
	// By default it is looking at the origin of the world coordinate system [0,0,0]
	cam.setPosition(50,150,-500);
	cam.lookAt(0,0,0);
	// Attach the camera to the world
	world.addCamera( cam );
	// Create the root group, the banch node for all objects in our world
	var bg:Group = new Group();
	// and attach it to the world. this node is responisble 
	// for drawing all its ( possibly transformed child nodes
	world.setRootGroup( bg );
	// Create the scen and attach it to the rootGroup
	createScene( bg );
	// Finally we start rendering the world
	world.render();
}

function createScene( bg:Group ):Void {
	// First we create a TransformationGroup
//	var tg:TransformGroup = new TransformGroup();
	// We create Transform3D to carry out a transformation in 3 dimensions
//	var rotation:Transform3D = new Transform3D();
	// We have to tell the Transformation what to do.
	// We want it to rotate our cube 
//	rotation.rot(20,30,0);
	// The transform is set in the transform group which will hold our cube
//	tg.setTransform( rotation );
	// Our cube is added to the transform group
//	tg.addChild( line );
	// Create the first plane
	var xyPlane:Object3D = new Plane3D(100,100,10,'quad');
	xyPlane.setSkin( new MixedSkin(0x00FF00, 20, 0, 40, 1));
	// To place our lines in world, let's add the coorinate axes - no transform applied
	var xAxis:Object3D = new Line3D( new Vector(-150,0,0), new Vector(150,0,0) );
	var yAxis:Object3D = new Line3D( new Vector(0,-150,0), new Vector(0,150,0) );
	var zAxis:Object3D = new Line3D( new Vector(0,0,-150), new Vector(0,0,150) );
	// Give the axes distinct colors
	xAxis.setSkin( new SimpleLineSkin( 1, 0xff0000, 100 ) ); // red
	yAxis.setSkin( new SimpleLineSkin( 1, 0x00ff00, 100 ) ); // green
	zAxis.setSkin( new SimpleLineSkin( 1, 0x0000ff, 100 ) ); // blue
	// Create the coorniate system group
	var coords:Group = new Group();
	coords.addChild(xAxis);
	coords.addChild(yAxis);
	coords.addChild(zAxis);
	// Add the coordinate system to the rootGroup
	bg.addChild( coords);
	bg.addChild(xyPlane);	
	// And finally the transformgroup is added as a child to the rootGroup
//	bg.addChild( tg );
}
// Start creating the world
init();